summaryrefslogtreecommitdiffstats
path: root/googletest/xcode
diff options
context:
space:
mode:
authorvpfautz <v.pfautz@gmx.net>2017-02-26 18:15:33 (GMT)
committervpfautz <v.pfautz@gmx.net>2017-02-26 18:15:33 (GMT)
commita2451c74038fa50870186c9c17b3393ead4b5981 (patch)
tree5c9d7a8b10b314d0d95bd561386dcd0b7c82e8ee /googletest/xcode
parentaa148eb2b7f70ede0eb10de34b6254826bfb34f4 (diff)
downloadgoogletest-a2451c74038fa50870186c9c17b3393ead4b5981.zip
googletest-a2451c74038fa50870186c9c17b3393ead4b5981.tar.gz
googletest-a2451c74038fa50870186c9c17b3393ead4b5981.tar.bz2
Fixed some typosrefs/pull/1030/head
Diffstat (limited to 'googletest/xcode')
-rwxr-xr-xgoogletest/xcode/Scripts/versiongenerate.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/googletest/xcode/Scripts/versiongenerate.py b/googletest/xcode/Scripts/versiongenerate.py
index 81de8c9..a6abb8b 100755
--- a/googletest/xcode/Scripts/versiongenerate.py
+++ b/googletest/xcode/Scripts/versiongenerate.py
@@ -42,7 +42,7 @@
1. The AC_INIT macro will be contained within the first 1024 characters
of configure.ac
2. The version string will be 3 integers separated by periods and will be
- surrounded by squre brackets, "[" and "]" (e.g. [1.0.1]). The first
+ surrounded by square brackets, "[" and "]" (e.g. [1.0.1]). The first
segment represents the major version, the second represents the minor
version and the third represents the fix version.
3. No ")" character exists between the opening "(" and closing ")" of
@@ -68,7 +68,7 @@ config_file.close()
# Extract the version string from the AC_INIT macro
# The following init_expression means:
# Extract three integers separated by periods and surrounded by squre
# brackets(e.g. "[1.0.1]") between "AC_INIT(" and ")". Do not be greedy
# (*? is the non-greedy flag) since that would pull in everything between
# the first "(" and the last ")" in the file.
@@ -68,7 +68,7 @@ config_file.close()
# Extract the version string from the AC_INIT macro
# The following init_expression means:
-# Extract three integers separated by periods and surrounded by squre
+# Extract three integers separated by periods and surrounded by square
# brackets(e.g. "[1.0.1]") between "AC_INIT(" and ")". Do not be greedy
# (*? is the non-greedy flag) since that would pull in everything between